@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development Company LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,11 +32,28 @@ def alarm(metrics):
             "alarmName": u"test Alarm " + UNICODE_CHAR,
             "oldState": "OK",
             "newState": "ALARM",
+            "severity": "LOW",
+            "link": "some-link",
+            "lifecycleState": "OPEN",
             "stateChangeReason": u"I am alarming!" + UNICODE_CHAR,
             "timestamp": time.time(),
             "metrics": metrics}
 
 
+def _parse_email(email_msg):
+    email = {"raw": email_msg}
+    email_lines = email_msg.splitlines()
+    email['subject'] = email_lines[3]
+    email['from'] = email_lines[4]
+    email['to'] = email_lines[5]
+    email['body'] = "\n".join(email_lines[6:])
+    print(email['from'])
+    print(email['to'])
+    print(email['subject'])
+    print(email['body'])
+    return email
+
+
 class smtpStub(object):
     def __init__(self, trap):
         self.trap = trap
@@ -101,14 +118,42 @@ class TestEmail(unittest.TestCase):
 
         self.notify(self._smtpStub, metrics)
 
-        email = self.trap.pop(0)
+        email = _parse_email(self.trap.pop(0))
 
-        self.assertRegexpMatches(email, "From: hpcs.mon@hp.com")
-        self.assertRegexpMatches(email, "To: me@here.com")
-        self.assertRegexpMatches(email, "Content-Type: text/plain")
-        self.assertRegexpMatches(email, "Alarm .test Alarm.")
-        self.assertRegexpMatches(email, "On host .foo1.")
-        self.assertRegexpMatches(email, UNICODE_CHAR_ENCODED)
+        self.assertRegexpMatches(email['from'], "From: hpcs.mon@hp.com")
+        self.assertRegexpMatches(email['to'], "To: me@here.com")
+        self.assertRegexpMatches(email['raw'], "Content-Type: text/plain")
+        self.assertRegexpMatches(email['subject'], "Subject: ALARM LOW .test Alarm.")
+        self.assertRegexpMatches(email['body'], "Alarm .test Alarm.")
+        self.assertRegexpMatches(email['body'], "On host .foo1.")
+        self.assertRegexpMatches(email['body'], UNICODE_CHAR_ENCODED)
+        self.assertRegexpMatches(email['body'], "Link: some-link")
+        self.assertRegexpMatches(email['body'], "Lifecycle state: OPEN")
+
+        return_value = self.trap.pop(0)
+        self.assertTrue(return_value)
+
+    def test_email_notification_target_host(self):
+        """Email with single host
+        """
+
+        metrics = []
+        metric_data = {'dimensions': {'hostname': u'foo1' + UNICODE_CHAR,
+                                      u'service' + UNICODE_CHAR: 'bar1',
+                                      u'target_host': u'some_where'}}
+        metrics.append(metric_data)
+
+        self.notify(self._smtpStub, metrics)
+
+        email = _parse_email(self.trap.pop(0))
+
+        self.assertRegexpMatches(email['from'], "From: hpcs.mon@hp.com")
+        self.assertRegexpMatches(email['to'], "To: me@here.com")
+        self.assertRegexpMatches(email['raw'], "Content-Type: text/plain")
+        self.assertRegexpMatches(email['subject'], "Subject: ALARM LOW .test Alarm.* Target: some_where")
+        self.assertRegexpMatches(email['body'], "Alarm .test Alarm.")
+        self.assertRegexpMatches(email['body'], "On host .foo1.")
+        self.assertRegexpMatches(email['body'], UNICODE_CHAR_ENCODED)
 
         return_value = self.trap.pop(0)
         self.assertTrue(return_value)
@@ -125,14 +170,17 @@ class TestEmail(unittest.TestCase):
 
         self.notify(self._smtpStub, metrics)
 
-        email = self.trap.pop(0)
+        email = _parse_email(self.trap.pop(0))
 
-        self.assertRegexpMatches(email, "From: hpcs.mon@hp.com")
-        self.assertRegexpMatches(email, "To: me@here.com")
-        self.assertRegexpMatches(email, "Content-Type: text/plain")
-        self.assertRegexpMatches(email, "Alarm .test Alarm.")
-        self.assertNotRegexpMatches(email, "foo1")
-        self.assertNotRegexpMatches(email, "foo2")
+        self.assertRegexpMatches(email['from'], "From: hpcs.mon@hp.com")
+        self.assertRegexpMatches(email['to'], "To: me@here.com")
+        self.assertRegexpMatches(email['raw'], "Content-Type: text/plain")
+        self.assertRegexpMatches(email['subject'], "Subject: ALARM LOW .test Alarm.")
+        self.assertRegexpMatches(email['body'], "Alarm .test Alarm.")
+        self.assertRegexpMatches(email['body'], "foo1")
+        self.assertRegexpMatches(email['body'], "foo2")
+        self.assertRegexpMatches(email['body'], "bar1")
+        self.assertRegexpMatches(email['body'], "bar2")
 
         return_value = self.trap.pop(0)
         self.assertTrue(return_value)
